@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2001, 2005 IBM Corporation and others.
+ * Copyright (c) 2000, 2006 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -24,25 +24,22 @@ import java.util.MissingResourceException;
 import java.util.ResourceBundle;
 
 import org.eclipse.cdt.core.dom.CDOM;
+import org.eclipse.cdt.core.dom.IPDOMManager;
 import org.eclipse.cdt.core.model.CoreModel;
 import org.eclipse.cdt.core.model.IWorkingCopy;
 import org.eclipse.cdt.core.parser.IScannerInfoProvider;
 import org.eclipse.cdt.core.resources.IConsole;
 import org.eclipse.cdt.core.resources.IPathEntryVariableManager;
 import org.eclipse.cdt.core.resources.ScannerProvider;
-import org.eclipse.cdt.core.search.SearchEngine;
 import org.eclipse.cdt.internal.core.CDTLogWriter;
 import org.eclipse.cdt.internal.core.CDescriptorManager;
 import org.eclipse.cdt.internal.core.PathEntryVariableManager;
-import org.eclipse.cdt.internal.core.index.domsourceindexer.AbstractIndexerRunner;
 import org.eclipse.cdt.internal.core.model.BufferManager;
 import org.eclipse.cdt.internal.core.model.CModelManager;
 import org.eclipse.cdt.internal.core.model.DeltaProcessor;
 import org.eclipse.cdt.internal.core.model.IBufferFactory;
 import org.eclipse.cdt.internal.core.model.Util;
-import org.eclipse.cdt.internal.core.search.indexing.IndexManager;
-import org.eclipse.cdt.internal.core.search.matching.MatchLocator;
-import org.eclipse.cdt.internal.core.search.processing.JobManager;
+import org.eclipse.cdt.internal.core.pdom.PDOMManager;
 import org.eclipse.core.resources.IProject;
 import org.eclipse.core.resources.IProjectDescription;
 import org.eclipse.core.resources.IResource;
@@ -86,10 +83,6 @@ public class CCorePlugin extends Plugin {
 	public static final String INDEXER_SIMPLE_ID = "CIndexer"; //$NON-NLS-1$
 	public static final String INDEXER_UNIQ_ID = PLUGIN_ID + "." + INDEXER_SIMPLE_ID; //$NON-NLS-1$
 	public final static String PREF_INDEXER = "indexer"; //$NON-NLS-1$
-	public final static String DEFAULT_INDEXER_SIMPLE_ID = "domsourceindexer"; //$NON-NLS-1$
-	public final static String NULL_INDEXER_SIMPLE_ID = "nullindexer"; //$NON-NLS-1$
-	public final static String NULL_INDEXER_UNIQUE_ID = PLUGIN_ID + "." + NULL_INDEXER_SIMPLE_ID ; //$NON-NLS-1$
-	public final static String DEFAULT_INDEXER_UNIQ_ID =  PLUGIN_ID + "." + DEFAULT_INDEXER_SIMPLE_ID; //$NON-NLS-1$
 	
 	public final static String ERROR_PARSER_SIMPLE_ID = "ErrorParser"; //$NON-NLS-1$
 
@@ -156,6 +149,8 @@ public class CCorePlugin extends Plugin {
 	private CDescriptorManager fDescriptorManager = new CDescriptorManager();
 
 	private CoreModel fCoreModel;
+	
+	private PDOMManager pdomManager;
 
 	private PathEntryVariableManager fPathEntryVariableManager;
 
@@ -289,8 +284,9 @@ public class CCorePlugin extends Plugin {
 		fCoreModel = CoreModel.getDefault();
 		fCoreModel.startup();
 
-		//Fired up the indexer
-		fCoreModel.startIndexing();
+		// Fire up the PDOM
+		pdomManager = new PDOMManager();
+		pdomManager.startup();
 
 		// Set the default for using the structual parse mode to build the CModel
 		getPluginPreferences().setDefault(PREF_USE_STRUCTURAL_PARSE_MODE, false);
@@ -612,6 +608,10 @@ public class CCorePlugin extends Plugin {
 		return fCoreModel;
 	}
 
+	public static IPDOMManager getPDOMManager() {
+		return getDefault().pdomManager;
+	}
+	
 	public IPathEntryVariableManager getPathEntryVariableManager() {
 		return fPathEntryVariableManager;
 	}
@@ -877,11 +877,13 @@ public class CCorePlugin extends Plugin {
 	 * @return
 	 */
 	public static IContentType getContentType(IProject project, String filename) {
+		// Always try in the workspace (for multi-language support)
 		// try with the project settings
 		if (project != null) {
 			try {
 				IContentTypeMatcher matcher = project.getContentTypeMatcher();
-				return matcher.findContentTypeFor(filename);
+				IContentType ct = matcher.findContentTypeFor(filename);
+				if (ct != null) return ct;
 			} catch (CoreException e) {
 				// ignore. 
 			}
@@ -893,11 +895,6 @@ public class CCorePlugin extends Plugin {
 
 
 	private static final String MODEL = CCorePlugin.PLUGIN_ID + "/debug/model" ; //$NON-NLS-1$
-	private static final String INDEXER = CCorePlugin.PLUGIN_ID + "/debug/indexer"; //$NON-NLS-1$
-	private static final String INDEX_MANAGER = CCorePlugin.PLUGIN_ID + "/debug/indexmanager"; //$NON-NLS-1$
-	private static final String INDEXER_TIMES = CCorePlugin.PLUGIN_ID + "/debug/indextimes"; //$NON-NLS-1$
-	private static final String SEARCH  = CCorePlugin.PLUGIN_ID + "/debug/search" ; //$NON-NLS-1$
-	private static final String MATCH_LOCATOR  = CCorePlugin.PLUGIN_ID + "/debug/matchlocator" ; //$NON-NLS-1$
 	private static final String PARSER = CCorePlugin.PLUGIN_ID + "/debug/parser" ; //$NON-NLS-1$
 	private static final String SCANNER = CCorePlugin.PLUGIN_ID + "/debug/scanner"; //$NON-NLS-1$
 	private static final String DELTA = CCorePlugin.PLUGIN_ID + "/debug/deltaprocessor" ; //$NON-NLS-1$
@@ -918,31 +915,9 @@ public class CCorePlugin extends Plugin {
 			option = Platform.getDebugOption(MODEL);
 			if(option != null) Util.VERBOSE_MODEL = option.equalsIgnoreCase("true") ; //$NON-NLS-1$
 			
-			boolean indexFlag = false;
-			option = Platform.getDebugOption(INDEX_MANAGER);
-			if(option != null) {
-				indexFlag = option.equalsIgnoreCase("true"); //$NON-NLS-1$
-				IndexManager.VERBOSE = indexFlag;
-			} //$NON-NLS-1$
-			
-			option = Platform.getDebugOption(INDEXER);
-			if(option != null) AbstractIndexerRunner.VERBOSE = option.equalsIgnoreCase("true") ; //$NON-NLS-1$
-		
-			option = Platform.getDebugOption(INDEXER_TIMES);
-			if (option != null) AbstractIndexerRunner.TIMING =  option.equalsIgnoreCase("true"); //$NON-NLS-1$
-			    
-			option = Platform.getDebugOption(SEARCH);
-			if(option != null) SearchEngine.VERBOSE = option.equalsIgnoreCase("true") ; //$NON-NLS-1$
-			
 			option = Platform.getDebugOption(DELTA);
 			if(option != null) DeltaProcessor.VERBOSE = option.equalsIgnoreCase("true") ; //$NON-NLS-1$
 			
-			option = Platform.getDebugOption(MATCH_LOCATOR);
-			if(option != null) MatchLocator.VERBOSE = option.equalsIgnoreCase("true") ; //$NON-NLS-1$
-
-			if (indexFlag == true){
-			   JobManager.VERBOSE = true; 	
-			}
 		}
 	}
 
@@ -961,4 +936,4 @@ public class CCorePlugin extends Plugin {
 	}
 
 	
-}
\ No newline at end of file
+}
